Changelog
=========

0.2.1 (2015-09-08)
------------------

- Calendar popup UI language default to english
  [keul]
- Added a way to change calendar language, but added the
  proper warning in the documentation
  [keul]
- Added the missing but needed ``calendar_formfield`` parameter.
  Calendar JavaScript was not working.
  [keul]

0.2.0 (2014-10-09)
------------------

- Added the Calendar field support and example
  [keul]

0.1.0a1 (2013-12-18)
--------------------

- Initial release
